@@ -84,7 +84,7 @@ sub _draw {
                 '-x'      => $x,
                 '-y'      => $y,
                 '-width'  => $node->get_branch_width,
-                '-stroke' => $node->get_branch_color,
+                '-stroke' => $node->get_node_outline_colour,
                 '-fill'   => $node->get_node_colour,
                 '-url'    => $node->get_link,
             );
@@ -179,7 +179,7 @@ sub _draw_collapsed {
             '-x3'     => $x2,
             '-y3'     => $y1 - $cladew / 2.7 * $td->_get_scaley + $padding,
             '-fill'   => $node->get_node_colour,
-            '-stroke' => $node->get_branch_color,
+            '-stroke' => $node->get_node_outline_colour,
             '-width'  => $td->get_branch_width($node),
             '-url'    => $node->get_link,
             'id'      => 'collapsed' . $node->get_id,
@@ -215,7 +215,7 @@ sub _draw_collapsed {
             '-x3'     => $x2,
             '-y3'     => $y1 - $cladew / 2 * $td->_get_scaley + $padding,
             '-fill'   => $node->get_node_colour,
-            '-stroke' => $node->get_branch_color,
+            '-stroke' => $node->get_node_outline_colour,
             '-width'  => $td->get_branch_width($node),
             '-url'    => $node->get_link,
             'id'      => 'collapsed' . $node->get_id,
